@@ -9,24 +9,27 @@ from __future__ import absolute_import
 
 from .i18n import _
 from . import (
-    bdiff,
     mdiff,
+    pycompat,
 )
 
+
 def _findexactmatches(repo, added, removed):
     '''find renamed files that have no changes
 
     Takes a list of new filectxs and a list of removed filectxs, and yields
     (before, after) tuples of exact matches.
     '''
-    numfiles = len(added) + len(removed)
-
     # Build table of removed files: {hash(fctx.data()): [fctx, ...]}.
     # We use hash() to discard fctx.data() from memory.
     hashes = {}
-    for i, fctx in enumerate(removed):
-        repo.ui.progress(_('searching for exact renames'), i, total=numfiles,
-                         unit=_('files'))
+    progress = repo.ui.makeprogress(
+        _(b'searching for exact renames'),
+        total=(len(added) + len(removed)),
+        unit=_(b'files'),
+    )
+    for fctx in removed:
+        progress.increment()
         h = hash(fctx.data())
         if h not in hashes:
             hashes[h] = [fctx]
@@ -34,9 +37,8 @@ def _findexactmatches(repo, added, removed):
             hashes[h].append(fctx)
 
     # For each added file, see if it corresponds to a removed file.
-    for i, fctx in enumerate(added):
-        repo.ui.progress(_('searching for exact renames'), i + len(removed),
-                total=numfiles, unit=_('files'))
+    for fctx in added:
+        progress.increment()
         adata = fctx.data()
         h = hash(adata)
         for rfctx in hashes.get(h, []):
@@ -46,20 +48,22 @@ def _findexactmatches(repo, added, removed):
                 break
 
     # Done
-    repo.ui.progress(_('searching for exact renames'), None)
+    progress.complete()
+
 
 def _ctxdata(fctx):
     # lazily load text
     orig = fctx.data()
     return orig, mdiff.splitnewlines(orig)
 
+
 def _score(fctx, otherdata):
     orig, lines = otherdata
     text = fctx.data()
-    # bdiff.blocks() returns blocks of matching lines
+    # mdiff.blocks() returns blocks of matching lines
     # count the number of bytes in each
     equal = 0
-    matches = bdiff.blocks(text, orig)
+    matches = mdiff.blocks(text, orig)
     for x1, x2, y1, y2 in matches:
         for line in lines[y1:y2]:
             equal += len(line)
@@ -67,9 +71,11 @@ def _score(fctx, otherdata):
     lengths = len(text) + len(orig)
     return equal * 2.0 / lengths
 
+
 def score(fctx1, fctx2):
     return _score(fctx1, _ctxdata(fctx2))
 
+
 def _findsimilarmatches(repo, added, removed, threshold):
     '''find potentially renamed files based on similar file content
 
@@ -77,10 +83,11 @@ def _findsimilarmatches(repo, added, removed, threshold):
     (before, after, score) tuples of partial matches.
     '''
     copies = {}
-    for i, r in enumerate(removed):
-        repo.ui.progress(_('searching for similar files'), i,
-                         total=len(removed), unit=_('files'))
-
+    progress = repo.ui.makeprogress(
+        _(b'searching for similar files'), unit=_(b'files'), total=len(removed)
+    )
+    for r in removed:
+        progress.increment()
         data = None
         for a in added:
             bestscore = copies.get(a, (None, threshold))[1]
@@ -89,15 +96,17 @@ def _findsimilarmatches(repo, added, removed, threshold):
             myscore = _score(a, data)
             if myscore > bestscore:
                 copies[a] = (r, myscore)
-    repo.ui.progress(_('searching'), None)
+    progress.complete()
 
-    for dest, v in copies.iteritems():
+    for dest, v in pycompat.iteritems(copies):
         source, bscore = v
         yield source, dest, bscore
 
+
 def _dropempty(fctxs):
     return [x for x in fctxs if x.size() > 0]
 
+
 def findrenames(repo, added, removed, threshold):
     '''find renamed files -- yields (before, after, score) tuples'''
     wctx = repo[None]
@@ -118,6 +127,7 @@ def findrenames(repo, added, removed, threshold):
     # If the user requested similar files to be matched, search for them also.
     if threshold < 1.0:
         addedfiles = [x for x in addedfiles if x not in matchedfiles]
-        for (a, b, score) in _findsimilarmatches(repo, addedfiles,
-                                                 removedfiles, threshold):
+        for (a, b, score) in _findsimilarmatches(
+            repo, addedfiles, removedfiles, threshold
+        ):
             yield (a.path(), b.path(), score)
